==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/IgnoreFileOptions.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.110Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.IgnoreFileOptions")
@software.amazon.jsii.Jsii.Proxy(IgnoreFileOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IgnoreFileOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Filter out comment lines?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFilterCommentLines() {
        return null;
    }

    /**
     * (experimental) Filter out blank/empty lines?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFilterEmptyLines() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<IgnoreFileOptions> {
        java.lang.Boolean filterCommentLines;
        java.lang.Boolean filterEmptyLines;

        /**
         * Sets the value of {@link IgnoreFileOptions#getFilterCommentLines}
         * @param filterCommentLines Filter out comment lines?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filterCommentLines(java.lang.Boolean filterCommentLines) {
            this.filterCommentLines = filterCommentLines;
            return this;
        }

        /**
         * Sets the value of {@link IgnoreFileOptions#getFilterEmptyLines}
         * @param filterEmptyLines Filter out blank/empty lines?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filterEmptyLines(java.lang.Boolean filterEmptyLines) {
            this.filterEmptyLines = filterEmptyLines;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IgnoreFileOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public IgnoreFileOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IgnoreFileOptions {
        private final java.lang.Boolean filterCommentLines;
        private final java.lang.Boolean filterEmptyLines;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filterCommentLines = software.amazon.jsii.Kernel.get(this, "filterCommentLines", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.filterEmptyLines = software.amazon.jsii.Kernel.get(this, "filterEmptyLines", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filterCommentLines = builder.filterCommentLines;
            this.filterEmptyLines = builder.filterEmptyLines;
        }

        @Override
        public final java.lang.Boolean getFilterCommentLines() {
            return this.filterCommentLines;
        }

        @Override
        public final java.lang.Boolean getFilterEmptyLines() {
            return this.filterEmptyLines;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilterCommentLines() != null) {
                data.set("filterCommentLines", om.valueToTree(this.getFilterCommentLines()));
            }
            if (this.getFilterEmptyLines() != null) {
                data.set("filterEmptyLines", om.valueToTree(this.getFilterEmptyLines()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.IgnoreFileOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IgnoreFileOptions.Jsii$Proxy that = (IgnoreFileOptions.Jsii$Proxy) o;

            if (this.filterCommentLines != null ? !this.filterCommentLines.equals(that.filterCommentLines) : that.filterCommentLines != null) return false;
            return this.filterEmptyLines != null ? this.filterEmptyLines.equals(that.filterEmptyLines) : that.filterEmptyLines == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filterCommentLines != null ? this.filterCommentLines.hashCode() : 0;
            result = 31 * result + (this.filterEmptyLines != null ? this.filterEmptyLines.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.80.4-sources.jar: io/github/cdklabs/projen/IgnoreFileOptions.java <==
package io.github.cdklabs.projen;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-28T17:20:28.903Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.IgnoreFileOptions")
@software.amazon.jsii.Jsii.Proxy(IgnoreFileOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IgnoreFileOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Filter out comment lines?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFilterCommentLines() {
        return null;
    }

    /**
     * (experimental) Filter out blank/empty lines?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getFilterEmptyLines() {
        return null;
    }

    /**
     * (experimental) Patterns to add to the ignore file.
     * <p>
     * Default: []
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getIgnorePatterns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<IgnoreFileOptions> {
        java.lang.Boolean filterCommentLines;
        java.lang.Boolean filterEmptyLines;
        java.util.List<java.lang.String> ignorePatterns;

        /**
         * Sets the value of {@link IgnoreFileOptions#getFilterCommentLines}
         * @param filterCommentLines Filter out comment lines?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filterCommentLines(java.lang.Boolean filterCommentLines) {
            this.filterCommentLines = filterCommentLines;
            return this;
        }

        /**
         * Sets the value of {@link IgnoreFileOptions#getFilterEmptyLines}
         * @param filterEmptyLines Filter out blank/empty lines?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filterEmptyLines(java.lang.Boolean filterEmptyLines) {
            this.filterEmptyLines = filterEmptyLines;
            return this;
        }

        /**
         * Sets the value of {@link IgnoreFileOptions#getIgnorePatterns}
         * @param ignorePatterns Patterns to add to the ignore file.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ignorePatterns(java.util.List<java.lang.String> ignorePatterns) {
            this.ignorePatterns = ignorePatterns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IgnoreFileOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public IgnoreFileOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IgnoreFileOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IgnoreFileOptions {
        private final java.lang.Boolean filterCommentLines;
        private final java.lang.Boolean filterEmptyLines;
        private final java.util.List<java.lang.String> ignorePatterns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.filterCommentLines = software.amazon.jsii.Kernel.get(this, "filterCommentLines", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.filterEmptyLines = software.amazon.jsii.Kernel.get(this, "filterEmptyLines", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.ignorePatterns = software.amazon.jsii.Kernel.get(this, "ignorePatterns", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.filterCommentLines = builder.filterCommentLines;
            this.filterEmptyLines = builder.filterEmptyLines;
            this.ignorePatterns = builder.ignorePatterns;
        }

        @Override
        public final java.lang.Boolean getFilterCommentLines() {
            return this.filterCommentLines;
        }

        @Override
        public final java.lang.Boolean getFilterEmptyLines() {
            return this.filterEmptyLines;
        }

        @Override
        public final java.util.List<java.lang.String> getIgnorePatterns() {
            return this.ignorePatterns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getFilterCommentLines() != null) {
                data.set("filterCommentLines", om.valueToTree(this.getFilterCommentLines()));
            }
            if (this.getFilterEmptyLines() != null) {
                data.set("filterEmptyLines", om.valueToTree(this.getFilterEmptyLines()));
            }
            if (this.getIgnorePatterns() != null) {
                data.set("ignorePatterns", om.valueToTree(this.getIgnorePatterns()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.IgnoreFileOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IgnoreFileOptions.Jsii$Proxy that = (IgnoreFileOptions.Jsii$Proxy) o;

            if (this.filterCommentLines != null ? !this.filterCommentLines.equals(that.filterCommentLines) : that.filterCommentLines != null) return false;
            if (this.filterEmptyLines != null ? !this.filterEmptyLines.equals(that.filterEmptyLines) : that.filterEmptyLines != null) return false;
            return this.ignorePatterns != null ? this.ignorePatterns.equals(that.ignorePatterns) : that.ignorePatterns == null;
        }

        @Override
        public final int hashCode() {
            int result = this.filterCommentLines != null ? this.filterCommentLines.hashCode() : 0;
            result = 31 * result + (this.filterEmptyLines != null ? this.filterEmptyLines.hashCode() : 0);
            result = 31 * result + (this.ignorePatterns != null ? this.ignorePatterns.hashCode() : 0);
            return result;
        }
    }
}
